@@ -25,6 +25,17 @@ class PathManager:
         package_path = wopmars.__path__[0]
         return package_path
 
+    @classmethod
+    def get_project_path(cls):
+        """
+        Returns the path to the project root
+
+        :return: path to the root of the project
+        """
+
+        project_path = os.path.join(cls.get_package_path(), "..")
+        return project_path
+
     @classmethod
     def get_test_path(cls):
         """
